@@ -1,11 +1,8 @@
 /*
-  Copyright (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            (c) 2007 Riccardo Iaconelli <ruphy@fsfe.org>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+    SPDX-FileCopyrightText: 2007 Riccardo Iaconelli <ruphy@fsfe.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "networkdialog.h"
@@ -22,16 +19,9 @@
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KSeparator>
-#include <kdnssd_version.h>
-#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
 #include <KDNSSD/ServiceBrowser>
 #include <KDNSSD/ServiceModel>
 #include <KDNSSD/PublicService>
-#else
-#include <DNSSD/ServiceBrowser>
-#include <DNSSD/ServiceModel>
-#include <DNSSD/PublicService>
-#endif
 #include <KConfigGroup>
 #include <QDialogButtonBox>
 
